==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_entities/equiplinearref_001/SourceDetails.java <==

package net.datastream.schemas.mp_entities.equiplinearref_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.USERID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CREATEDDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CREATEDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEUPDATED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UPDATEDBY" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "createddate",
    "createdby",
    "dateupdated",
    "updatedby"
})
@XmlRootElement(name = "SourceDetails")
public class SourceDetails {

    @XmlElement(name = "CREATEDDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME createddate;
    @XmlElement(name = "CREATEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type createdby;
    @XmlElement(name = "DATEUPDATED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME dateupdated;
    @XmlElement(name = "UPDATEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type updatedby;

    /**
     * Gets the value of the createddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getCREATEDDATE() {
        return createddate;
    }

    /**
     * Sets the value of the createddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setCREATEDDATE(DATETIME value) {
        this.createddate = value;
    }

    /**
     * Gets the value of the createdby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getCREATEDBY() {
        return createdby;
    }

    /**
     * Sets the value of the createdby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setCREATEDBY(USERID_Type value) {
        this.createdby = value;
    }

    /**
     * Gets the value of the dateupdated property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEUPDATED() {
        return dateupdated;
    }

    /**
     * Sets the value of the dateupdated property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEUPDATED(DATETIME value) {
        this.dateupdated = value;
    }

    /**
     * Gets the value of the updatedby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getUPDATEDBY() {
        return updatedby;
    }

    /**
     * Sets the value of the updatedby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setUPDATEDBY(USERID_Type value) {
        this.updatedby = value;
    }

}

==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_entities/equiplinearref_001/SourceDetails.java <==

package net.datastream.schemas.mp_entities.equiplinearref_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.USERID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CREATEDDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CREATEDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEUPDATED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UPDATEDBY" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "createddate",
    "createdby",
    "dateupdated",
    "updatedby"
})
@XmlRootElement(name = "SourceDetails")
public class SourceDetails {

    @XmlElement(name = "CREATEDDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME createddate;
    @XmlElement(name = "CREATEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type createdby;
    @XmlElement(name = "DATEUPDATED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME dateupdated;
    @XmlElement(name = "UPDATEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type updatedby;

    /**
     * Obtient la valeur de la propriété createddate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getCREATEDDATE() {
        return createddate;
    }

    /**
     * Définit la valeur de la propriété createddate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setCREATEDDATE(DATETIME value) {
        this.createddate = value;
    }

    /**
     * Obtient la valeur de la propriété createdby.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getCREATEDBY() {
        return createdby;
    }

    /**
     * Définit la valeur de la propriété createdby.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setCREATEDBY(USERID_Type value) {
        this.createdby = value;
    }

    /**
     * Obtient la valeur de la propriété dateupdated.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEUPDATED() {
        return dateupdated;
    }

    /**
     * Définit la valeur de la propriété dateupdated.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEUPDATED(DATETIME value) {
        this.dateupdated = value;
    }

    /**
     * Obtient la valeur de la propriété updatedby.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getUPDATEDBY() {
        return updatedby;
    }

    /**
     * Définit la valeur de la propriété updatedby.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setUPDATEDBY(USERID_Type value) {
        this.updatedby = value;
    }

}
